diff --git a/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js b/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
index eb20cac5..18058324 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
+++ b/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
@@ -24,7 +24,8 @@ define('pgadmin.node.database', [
         columns: ['name', 'datowner', 'comments'],
         hasStatistics: true,
         canDrop: true,
-        canDropCascade: false,
+        selectParentNodeOnDelete: true,
+        canDropCascade: true,
         statsPrettifyFields: [gettext('Size'), gettext('Size of temporary files')],
       });
   }
@@ -43,6 +44,7 @@ define('pgadmin.node.database', [
       canDrop: function(node) {
         return node.canDrop;
       },
+      selectParentNodeOnDelete: true,
       label: gettext('Database'),
       node_image: function() {
         return 'pg-icon-database';
diff --git a/web/pgadmin/browser/static/js/collection.js b/web/pgadmin/browser/static/js/collection.js
index 47c87715..d3b870e7 100644
--- a/web/pgadmin/browser/static/js/collection.js
+++ b/web/pgadmin/browser/static/js/collection.js
@@ -86,6 +86,7 @@ define([
       hasCollectiveStatistics: true,
       canDrop: true,
       canDropCascade: true,
+      selectParentNodeOnDelete: false,
       showProperties: function(item, data, panel) {
         var that = this,
           j = panel.$container.find('.obj_properties').first(),
diff --git a/web/pgadmin/browser/static/js/node.js b/web/pgadmin/browser/static/js/node.js
index b34b4f8e..99cdb4f1 100644
--- a/web/pgadmin/browser/static/js/node.js
+++ b/web/pgadmin/browser/static/js/node.js
@@ -569,6 +569,10 @@ define('pgadmin.browser.node', [
     dropPriority is set to 2 by default, override it when change is required
     */
     dropPriority: 2,
+    /******************************************************************************
+    select collection node on deletion.
+    */
+    selectParentNodeOnDelete: false,
     // List of common callbacks - that can be used for different
     // operations!
     callbacks: {
@@ -835,7 +839,16 @@ define('pgadmin.browser.node', [
                 if (res.success == 0) {
                   pgBrowser.report_error(res.errormsg, res.info);
                 } else {
-                  pgBrowser.removeTreeNode(i, true);
+                  // Remove the node from tree and set collection node as selected.
+                  var selectNextNode = true;
+                  if(obj.selectParentNodeOnDelete) {
+                    var prv_i = t.parent(i);
+                    setTimeout(function() {
+                      t.select(prv_i);
+                    }, 10);
+                    selectNextNode = false;
+                  }
+                  pgBrowser.removeTreeNode(i, selectNextNode);
                 }
                 return true;
               })
